#!/usr/bin/python

# Copyright 2013 William Witteman                                               
 
#This program is free software: you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation, either version 3 of the License, or
#(at your option) any later version.
#
#This program is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""
Take the output of the clinicaltrials.gov (a bunch of big xml files) and
spit out a CSV file with basic, ID, trialname, description info.
"""

import csv, sys
import xml.etree.ElementTree as ET

filelist = sys.argv[1:]

#debug print(filelist)

if len(filelist) == 0:
  print("There's nothing to do")
else:
  with open("clinicaltrials-us.csv","wb") as csvfile:
    trialwriter = csv.writer(csvfile)
    #debug trialwriter.writerow(["sep=,"])
    trialwriter.writerow(["NCT ID","Brief Title","Official Title", "Brief Summary"])
    for x in filelist:
      #debug print(x)
      try:
        tree = ET.parse(x)
        root = tree.getroot()
        onerow = ["","","",""]
        try:
          onerow[0] = root.find("id_info/nct_id").text.encode("utf-8")
        except:
          onerow[0] = ""
        try:
          onerow[1] = root.find("brief_title").text.encode("utf-8")

        except:
          onerow[1] = ""
        try:
          onerow[2] = root.find("official_title").text.encode("utf-8")

        except:
          onerow[2] = ""
        try:
          onerow[3] = root.find("brief_summary/textblock").text.encode("utf-8")
        except:
          onerow[3] = ""
      except:
        print("Error with this file: " + x)
        print(sys.exc_info())

      #debug print(onerow)
      trialwriter.writerow(onerow)


